Buffer class

Constructors

Buffer({required Terminal terminal, required bool isAltBuffer})

Properties

charset → Charset
final
currentLine → BufferLine
no setter
cursorX → int
Horizontal position of the cursor relative to the top-left cornor of the screen, starting from 0.
no setter
cursorY → int
Vertical position of the cursor relative to the top-left cornor of the screen, starting from 0.
no setter
hashCode → int
The hash code for this object.
no setterinherited
hasScrollableRegion → bool
no setter
height → int
no setter
isAltBuffer → bool
final
isInScrollableRegion → bool
no setter
isUserScrolling → bool
Indicated whether the terminal should automatically scroll to bottom when new lines are added. When user is scrolling, isUserScrolling is true and the automatical scroll-to-bottom behavior is disabled.
no setter
lines ↔ CircularList<BufferLine>
lines of the buffer. the length of lines should always be equal or greater than Terminal.viewHeight.
latefinal
marginBottom → int
no setter
marginTop → int
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scrollOffsetFromBottom → int
no setter
scrollOffsetFromTop → int
no setter
viewHeight → int
no setter
viewWidth → int
no setter

Methods

adjustSavedCursor(int dx, int dy) → dynamic
areaScrollDown(int lines) → void
areaScrollUp(int lines) → void
backspace() → void
carriageReturn() → void
clear() → void
clearScrollback() → void
convertRawLineToViewLine(int rawLine) → int
convertViewLineToRawLine(int viewLine) → int
cursorGoForward() → void
deleteChars(int count) → void
deleteLine() → void
deleteLines(int count) → void
eraseCharacters(int count) → void
eraseDisplay() → void
eraseDisplayFromCursor() → void
eraseDisplayToCursor() → void
eraseLine() → void
eraseLineFromCursor() → void
eraseLineToCursor() → void
getAreaScrollRange() → ScrollRange
getViewLine(int index) → BufferLine
get line in the viewport. index starts from 0, must be smaller than Terminal.viewHeight.
getVisibleLines() → List<BufferLine>
index() → void
https://vt100.net/docs/vt100-ug/chapter3.html#IND IND – Index
insertBlankCharacters(int count) → void
insertLine() → void
insertLines(int count) → void
moveCursorX(int offset) → void
moveCursorY(int offset) → void
movePosition(int offsetX, int offsetY) → void
newLine() → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
resetVerticalMargins() → void
resize(int oldWidth, int oldHeight, int newWidth, int newHeight) → void
restoreCursor() → void
reverseIndex() → void
https://vt100.net/docs/vt100-ug/chapter3.html#RI
saveCursor() → void
screenScrollDown(int lines) → void
screenScrollUp(int lines) → void
setCursorX(int cursorX) → void
setCursorY(int cursorY) → void
setPosition(int cursorX, int cursorY) → void
setScrollOffsetFromBottom(int offsetFromBottom) → void
setScrollOffsetFromTop(int offsetFromTop) → void
setVerticalMargins(int top, int bottom) → void
toString() → String
A string representation of this object.
inherited
write(String text) → void
Writes data to the _terminal. Terminal sequences or special characters are not interpreted and directly added to the buffer.
writeChar(int codePoint) → void
Writes a single character to the _terminal. Special chatacters are not interpreted and directly added to the buffer.

Operators

operator ==(Object other) → bool
The equality operator.
inherited