TextLayoutCache class

Constructors

TextLayoutCache(TextDirection textDirection, int maximumSize)

Properties

hashCode → int
The hash code for this object.
no setterinherited
length → int
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
textDirection → TextDirection
final

Methods

clear() → void
getLayoutFromCache(int key) → Paragraph?
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
performAndCacheLayout(String text, TextStyle style, int? key) → Paragraph
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited