InputBehaviorDefault class

Inheritance
Implementers

Constructors

InputBehaviorDefault()

Properties

acceptKeyStroke → bool
no setteroverride
hashCode → int
The hash code for this object.
no setterinherited
initEditingState → TextEditingValue
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onAction(TextInputAction action, TerminalUiInteraction terminal) → void
override
onKeyStroke(RawKeyEvent event, TerminalUiInteraction terminal) → void
override
onTextEdit(TextEditingValue value, TerminalUiInteraction terminal) → TextEditingValue?
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited