TerminalTextInputClient class

Constructors

TerminalTextInputClient(void onInput(TextEditingValue value), ActionHandler onAction)

Properties

currentAutofillScope AutofillScope?
no setter
currentTextEditingValue TextEditingValue?
no setter
hashCode int
The hash code for this object.
no setterinherited
onAction ActionHandler
final
onInput → void Function(TextEditingValue value)
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

connectionClosed() → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
performAction(TextInputAction action) → void
performPrivateCommand(String action, Map<String, dynamic> data) → void
showAutocorrectionPromptRect(int start, int end) → void
toString() String
A string representation of this object.
inherited
updateEditingValue(TextEditingValue value) → void
updateFloatingCursor(RawFloatingCursorPoint point) → void

Operators

operator ==(Object other) bool
The equality operator.
inherited