Keytab class

Constructors

Keytab({required String? name, required List<KeytabRecord> records})
Keytab.defaultKeytab()
factory
Keytab.parse(String source)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
name → String?
final
records → List<KeytabRecord>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited