KeytabRecord class

Constructors

KeytabRecord({required String qtKeyName, required TerminalKey key, required KeytabAction action, required bool? alt, required bool? ctrl, required bool? shift, required bool? anyModifier, required bool? ansi, required bool? appScreen, required bool? keyPad, required bool? appCursorKeys, required bool? appKeyPad, required bool? newLine, required bool? mac})

Properties

action ↔ KeytabAction
getter/setter pair
alt ↔ bool?
getter/setter pair
ansi ↔ bool?
getter/setter pair
anyModifier ↔ bool?
getter/setter pair
appCursorKeys ↔ bool?
getter/setter pair
appKeyPad ↔ bool?
getter/setter pair
appScreen ↔ bool?
getter/setter pair
ctrl ↔ bool?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
key ↔ TerminalKey
getter/setter pair
keyPad ↔ bool?
getter/setter pair
mac ↔ bool?
getter/setter pair
newLine ↔ bool?
getter/setter pair
qtKeyName ↔ String
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
shift ↔ bool?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited