LineReader class

Constructors

LineReader(String line)

Properties

done → bool
no setter
hashCode → int
The hash code for this object.
no setterinherited
line → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
peek([int count = 1]) → String?
readString() → String
readUntil(Pattern pattern, {bool inclusive = false}) → String
skipWhitespace() → void
take([int count = 1]) → String?
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited