Cursor class

Keeps the default style of newly created cells.

Constructors

Cursor({required int fg, required int bg, required int flags})

Properties

bg ↔ int
getter/setter pair
fg ↔ int
getter/setter pair
flags ↔ int
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited