Terminal class

Implemented types
Mixed-in types

Constructors

Terminal({TerminalBackend? backend, BellHandler onBell = _defaultBellHandler, TitleChangeHandler onTitleChange = _defaultTitleHandler, IconChangeHandler onIconChange = _defaultIconHandler, PlatformBehavior platform = PlatformBehaviors.unix, TerminalTheme theme = TerminalThemes.defaultTheme, required int maxLines})

Properties

applicationCursorKeys → bool
DECCKM – Cursor Keys Mode (DEC Private)
no setter
autoWrapMode → bool
no setter
backend → TerminalBackend?
final
backendExited → Future<int>
Future that fires when the backend has exited
no setteroverride
backgroundColor → int
color code for the background
no setteroverride
blinkingCursor → bool
no setter
bracketedPasteMode → bool
Bracketed Paste Mode
no setter
buffer → Buffer
the current buffer
no setteroverride
bufferHeight → int
the total buffer height
no setteroverride
composingString → String
returns the current composing string. '' when there is no composing going on
no setteroverride
currentLine → BufferLine?
current line
no setteroverride
currentSearchHit ↔ int?
gets the current search hit
getter/setter pairoverride
cursor ↔ Cursor
latefinal
cursorColor → int
color code for the cursor
no setteroverride
cursorX → int
cursor x coordinate
no setteroverride
cursorY → int
cursor y coordinate
no setteroverride
debug → DebugHandler
final
dirty → bool
flag that indicates if the terminal is dirty (since the last time this flag has been queried)
no setteroverride
hashCode → int
The hash code for this object.
no setterinherited
invisibleHeight → int
the part of the buffer that is not visible (scrollback)
no setteroverride
isReady → bool
flag that indicates if the Terminal is ready
no setteroverride
isTerminated → bool
flag that indicates if the backend is already terminated
no setteroverride
isUserSearchActive ↔ bool
gets if a user search is active
getter/setter pairoverride
keytab → Keytab
final
lineFeedMode → bool
LNM – Line Feed/New Line Mode
no setter
listeners → Set<_VoidCallback>
finalinherited
maxLines → int
no setter
mouseMode → MouseMode
no setter
newLineMode → bool
See: lineFeedMode
no setter
numberOfSearchHits → int
gets the number of search hits
no setteroverride
onBell → BellHandler
final
onIconChange → IconChangeHandler
final
onTitleChange → IconChangeHandler
final
originMode → bool
DECOM – Origin Mode (DEC Private)
no setter
platform → PlatformBehavior
platform behavior for this terminal
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scrollOffsetFromBottom → int
the ViewPort scroll offset from the bottom
no setteroverride
scrollOffsetFromTop → int
the ViewPort scroll offset from the top
no setteroverride
selectedText → String?
selected text defined by selection
no setteroverride
selection → Selection?
object that describes details about the current selection
no setteroverride
showCursor → bool
true when the cursor shall be shown, otherwise false
no setteroverride
slowMotion → bool
no setter
tabs → Tabs
final
terminalHeight → int
terminal height (view port)
no setteroverride
terminalWidth → int
terminal width (view port)
no setteroverride
theme → TerminalTheme
The theme associated with this Terminal
final
userSearchOptions ↔ TerminalSearchOptions
gets the current user search options
getter/setter pairoverride
userSearchPattern ↔ String?
the search pattern of a currently active search or null
getter/setter pairoverride
userSearchResult → TerminalSearchResult
returns the list of search hits
no setteroverride
viewHeight → int
no setter
viewWidth → int
no setter
visibleHeight → int
no setter

Methods

addListener(_VoidCallback listener) → void
inherited
clearSelection() → void
clears the selection
override
convertViewLineToRawLine(int viewLine) → int
converts the given view line (view port line) index to its position in the overall buffer
override
getSelectedText() → String?
getVisibleLines() → List<BufferLine>
returns the visible lines
override
isUsingAltBuffer() → bool
indication if the alternative buffer is currently used
override
isUsingMainBuffer() → bool
keyInput(TerminalKey key, {bool ctrl = false, bool alt = false, bool shift = false, bool mac = false, String? character}) → void
notifies the Terminal about key input
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyListeners() → void
inherited
onMouseDoubleTap(Position position) → void
notify the Terminal about a mouse double tap
override
onMouseTap(Position position) → void
notify the Terminal about a mouse tap
override
onPanStart(Position position) → void
notify the Terminal about a pan start
override
onPanUpdate(Position position) → void
notify the Terminal about a pan update
override
paste(String data) → void
paste clipboard content to the Terminal
override
raiseOnInput(String input) → void
notifies the Terminal about user input
override
refresh() → void
refreshes the Terminal (notifies listeners and sets it to dirty)
override
removeListener(_VoidCallback listener) → void
inherited
resize(int newWidth, int newHeight, int newPixelWidth, int newPixelHeight) → void
Resize the terminal screen. newWidth and newHeight should be greater than 0. Text reflow is currently not implemented and will be avaliable in the future.
override
selectAll() → void
select the whole buffer
override
selectWordOrRow(Position position) → void
setApplicationCursorKeys(bool enabled) → void
setAutoWrapMode(bool enabled) → void
setBlinkingCursor(bool enabled) → void
setBracketedPasteMode(bool enabled) → void
setInsertMode() → void
setLineFeedMode() → void
setMouseMode(MouseMode mode) → void
setNewLineMode() → void
setOriginMode(bool enabled) → void
setReplaceMode() → void
setScreenMode(bool enabled) → void
setScrollOffsetFromBottom(int scrollOffset) → void
sets the scroll offset from bottom (scrolling)
override
setShowCursor(bool showCursor) → void
setSlowMotion(bool enabled) → void
tab() → void
tabClearAtCursor() → void
tabSetAtCursor() → void
terminateBackend() → void
terminates the backend. If already terminated, nothing happens
override
toString() → String
A string representation of this object.
inherited
updateComposingString(String value) → void
update the composing string. This gets called by the input handling part of the terminal
override
useAltBuffer() → void
useMainBuffer() → void
write(String text) → void
Writes data to the terminal. Terminal sequences and special characters are interpreted.
override
writeChar(int codePoint) → void
Writes data to the terminal. Special characters are interpreted.

Operators

operator ==(Object other) → bool
The equality operator.
inherited