TerminalStyle class

Constructors

TerminalStyle({List<String> fontFamily = defaultFontFamily, double fontSize = 14, double fontWidthScaleFactor = 1.0, double fontHeightScaleFactor = 1.1, TextStyleProvider? textStyleProvider, bool ignoreBoldFlag = false})
const

Properties

fontFamily → List<String>
final
fontHeightScaleFactor → double
final
fontSize → double
final
fontWidthScaleFactor → double
final
hashCode → int
The hash code for this object.
no setterinherited
ignoreBoldFlag → bool
final
props → List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stringify → bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited
textStyleProvider → TextStyleProvider?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

defaultFontFamily → const List<String>