Observable mixin

Mixin applications

Properties

hashCode → int
The hash code for this object.
no setterinherited
listeners → Set<_VoidCallback>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

addListener(_VoidCallback listener) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyListeners() → void
removeListener(_VoidCallback listener) → void
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited